@@ -5,7 +5,7 @@
 # This software may be used and distributed according to the terms of the
 # GNU General Public License version 2 or any later version.
 
-from __future__ import absolute_import
+from __future__ import absolute_import, division
 
 import ctypes
 import ctypes.util
@@ -13,11 +13,13 @@ import os
 import socket
 import stat as statmod
 
+from ..pycompat import getattr
 from .. import (
     encoding,
     pycompat,
 )
 
+
 def _mode_to_kind(mode):
     if statmod.S_ISREG(mode):
         return statmod.S_IFREG
@@ -35,8 +37,9 @@ def _mode_to_kind(mode):
         return statmod.S_IFSOCK
     return mode
 
+
 def listdir(path, stat=False, skip=None):
-    '''listdir(path, stat=False) -> list_of_tuples
+    """listdir(path, stat=False) -> list_of_tuples
 
     Return a sorted list containing information about the entries
     in the directory.
@@ -48,7 +51,7 @@ def listdir(path, stat=False, skip=None):
     Otherwise, each element is a 2-tuple:
 
       (name, type)
-    '''
+    """
     result = []
     prefix = path
     if not prefix.endswith(pycompat.ossep):
@@ -65,13 +68,14 @@ def listdir(path, stat=False, skip=None):
             result.append((fn, _mode_to_kind(st.st_mode)))
     return result
 
+
 if not pycompat.iswindows:
     posixfile = open
 
     _SCM_RIGHTS = 0x01
     _socklen_t = ctypes.c_uint
 
-    if pycompat.sysplatform.startswith('linux'):
+    if pycompat.sysplatform.startswith(b'linux'):
         # socket.h says "the type should be socklen_t but the definition of
         # the kernel is incompatible with this."
         _cmsg_len_t = ctypes.c_size_t
@@ -111,12 +115,15 @@ if not pycompat.iswindows:
     _recvmsg = getattr(_libc, 'recvmsg', None)
     if _recvmsg:
         _recvmsg.restype = getattr(ctypes, 'c_ssize_t', ctypes.c_long)
-        _recvmsg.argtypes = (ctypes.c_int, ctypes.POINTER(_msghdr),
-                             ctypes.c_int)
+        _recvmsg.argtypes = (
+            ctypes.c_int,
+            ctypes.POINTER(_msghdr),
+            ctypes.c_int,
+        )
     else:
         # recvmsg isn't always provided by libc; such systems are unsupported
         def _recvmsg(sockfd, msg, flags):
-            raise NotImplementedError('unsupported platform')
+            raise NotImplementedError(b'unsupported platform')
 
     def _CMSG_FIRSTHDR(msgh):
         if msgh.msg_controllen < ctypes.sizeof(_cmsghdr):
@@ -132,10 +139,15 @@ if not pycompat.iswindows:
         dummy = (ctypes.c_ubyte * 1)()
         iov = _iovec(ctypes.cast(dummy, ctypes.c_void_p), ctypes.sizeof(dummy))
         cbuf = ctypes.create_string_buffer(256)
-        msgh = _msghdr(None, 0,
-                       ctypes.pointer(iov), 1,
-                       ctypes.cast(cbuf, ctypes.c_void_p), ctypes.sizeof(cbuf),
-                       0)
+        msgh = _msghdr(
+            None,
+            0,
+            ctypes.pointer(iov),
+            1,
+            ctypes.cast(cbuf, ctypes.c_void_p),
+            ctypes.sizeof(cbuf),
+            0,
+        )
         r = _recvmsg(sockfd, ctypes.byref(msgh), 0)
         if r < 0:
             e = ctypes.get_errno()
@@ -145,14 +157,18 @@ if not pycompat.iswindows:
         cmsg = _CMSG_FIRSTHDR(msgh)
         if not cmsg:
             return []
-        if (cmsg.cmsg_level != socket.SOL_SOCKET or
-            cmsg.cmsg_type != _SCM_RIGHTS):
+        if (
+            cmsg.cmsg_level != socket.SOL_SOCKET
+            or cmsg.cmsg_type != _SCM_RIGHTS
+        ):
             return []
         rfds = ctypes.cast(cmsg.cmsg_data, ctypes.POINTER(ctypes.c_int))
-        rfdscount = ((cmsg.cmsg_len - _cmsghdr.cmsg_data.offset) /
-                     ctypes.sizeof(ctypes.c_int))
+        rfdscount = (
+            cmsg.cmsg_len - _cmsghdr.cmsg_data.offset
+        ) // ctypes.sizeof(ctypes.c_int)
         return [rfds[i] for i in pycompat.xrange(rfdscount)]
 
+
 else:
     import msvcrt
 
@@ -188,17 +204,25 @@ else:
 
     # types of parameters of C functions used (required by pypy)
 
-    _kernel32.CreateFileA.argtypes = [_LPCSTR, _DWORD, _DWORD, ctypes.c_void_p,
-        _DWORD, _DWORD, _HANDLE]
+    _kernel32.CreateFileA.argtypes = [
+        _LPCSTR,
+        _DWORD,
+        _DWORD,
+        ctypes.c_void_p,
+        _DWORD,
+        _DWORD,
+        _HANDLE,
+    ]
     _kernel32.CreateFileA.restype = _HANDLE
 
     def _raiseioerror(name):
         err = ctypes.WinError()
-        raise IOError(err.errno, r'%s: %s' % (encoding.strfromlocal(name),
-                                              err.strerror))
+        raise IOError(
+            err.errno, '%s: %s' % (encoding.strfromlocal(name), err.strerror)
+        )
 
     class posixfile(object):
-        '''a file object aiming for POSIX-like semantics
+        """a file object aiming for POSIX-like semantics
 
         CPython's open() returns a file that was opened *without* setting the
         _FILE_SHARE_DELETE flag, which causes rename and unlink to abort.
@@ -207,7 +231,7 @@ else:
         renamed and deleted while they are held open.
         Note that if a file opened with posixfile is unlinked, the file
         remains but cannot be opened again or be recreated under the same name,
-        until all reading processes have closed the file.'''
+        until all reading processes have closed the file."""
 
         def __init__(self, name, mode=b'r', bufsize=-1):
             if b'b' in mode:
@@ -233,11 +257,17 @@ else:
                 creation = _OPEN_ALWAYS
                 flags |= _O_APPEND
             else:
-                raise ValueError(r"invalid mode: %s" % pycompat.sysstr(mode))
+                raise ValueError("invalid mode: %s" % pycompat.sysstr(mode))
 
-            fh = _kernel32.CreateFileA(name, access,
-                    _FILE_SHARE_READ | _FILE_SHARE_WRITE | _FILE_SHARE_DELETE,
-                    None, creation, _FILE_ATTRIBUTE_NORMAL, None)
+            fh = _kernel32.CreateFileA(
+                name,
+                access,
+                _FILE_SHARE_READ | _FILE_SHARE_WRITE | _FILE_SHARE_DELETE,
+                None,
+                creation,
+                _FILE_ATTRIBUTE_NORMAL,
+                None,
+            )
             if fh == _INVALID_HANDLE_VALUE:
                 _raiseioerror(name)
 
@@ -250,8 +280,8 @@ else:
             # unfortunately, f.name is '<fdopen>' at this point -- so we store
             # the name on this wrapper. We cannot just assign to f.name,
             # because that attribute is read-only.
-            object.__setattr__(self, r'name', name)
-            object.__setattr__(self, r'_file', f)
+            object.__setattr__(self, 'name', name)
+            object.__setattr__(self, '_file', f)
 
         def __iter__(self):
             return self._file
@@ -260,14 +290,16 @@ else:
             return getattr(self._file, name)
 
         def __setattr__(self, name, value):
-            '''mimics the read-only attributes of Python file objects
+            """mimics the read-only attributes of Python file objects
             by raising 'TypeError: readonly attribute' if someone tries:
               f = posixfile('foo.txt')
-              f.name = 'bla'  '''
+              f.name = 'bla'
+            """
             return self._file.__setattr__(name, value)
 
         def __enter__(self):
-            return self._file.__enter__()
+            self._file.__enter__()
+            return self
 
         def __exit__(self, exc_type, exc_value, exc_tb):
             return self._file.__exit__(exc_type, exc_value, exc_tb)
